@@ -1,8 +1,9 @@
+use 5.008;
+
 package Test::Data;
 use strict;
 
-use vars qw($VERSION);
-$VERSION = '1.23';
+our $VERSION = '1.243';
 
 use Carp qw(carp);
 
@@ -29,27 +30,22 @@ and values of data and variables.
 
 $Exporter::Verbose = 0;
 
-sub import 
-	{
+sub import {
     my $self   = shift;
     my $caller = caller;
 
-	foreach my $package ( @_ )
-		{
+	foreach my $package ( @_ ) {
 		my $full_package = "Test::Data::$package";
 		eval{ eval "require $full_package" };
-		if( $@ )
-			{
+		if( $@ ) {
 			carp "Could not require Test::Data::$package: $@";
 			}
 
-		$full_package->export($caller);
+		$full_package->Exporter::export($caller);
 		}
 
 	}
 
-sub VERSION { return $VERSION }
-
 =head2 Functions
 
 Plug-in modules define functions for each data type.  See the
@@ -59,7 +55,7 @@ appropriate module.
 
 The Test::Data module simply emports functions from Test::Data::*
 modules.  Each module defines a self-contained function, and puts
-that function name into @EXPORT.  Test::Data defines its own 
+that function name into @EXPORT.  Test::Data defines its own
 import function, but that does not matter to the plug-in modules.
 
 If you want to write a plug-in module, follow the example of one
@@ -71,7 +67,7 @@ find it.
 
 I'm not a very good Windows Perler, so some things don't work as
 they should on Windows. I recently got a Windows box so I can
-test things, but if you run into problems, I can use all the 
+test things, but if you run into problems, I can use all the
 patches or advice you care to send.
 
 =head1 SEE ALSO
@@ -94,10 +90,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2012 brian d foy.  All rights reserved.
+Copyright © 2002-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
 
