@@ -1,14 +1,15 @@
+use 5.008;
+
 package Test::Data::Hash;
 use strict;
 
-use base qw(Exporter);
-use vars qw(@EXPORT $VERSION);
+use Exporter qw(import);
 
-@EXPORT = qw(exists_ok not_exists_ok
+our @EXPORT = qw(exists_ok not_exists_ok
 	hash_value_defined_ok hash_value_undef_ok
 	hash_value_true_ok hash_value_false_ok);
 
-$VERSION = '1.23';
+our $VERSION = '1.243';
 
 use Test::Builder;
 my $Test = Test::Builder->new();
@@ -87,8 +88,7 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_undef_ok($\%;$)
-	{
+sub hash_value_undef_ok($\%;$) {
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is undef";
@@ -103,8 +103,7 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_true_ok($\%;$)
-	{
+sub hash_value_true_ok($\%;$) {
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is true";
@@ -119,8 +118,7 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_false_ok($\%;$)
-	{
+sub hash_value_false_ok($\%;$) {
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is false";
@@ -150,10 +148,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2012 brian d foy.  All rights reserved.
+Copyright © 2002-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
 
